@@ -1,5 +1,6 @@
 /* enchant
  * Copyright (C) 2003,2004 Dom Lachowicz
+ * Copyright (C) 2017-2024 Reuben Thomas
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -170,8 +171,7 @@ aspell_provider_list_dicts (EnchantProvider * me _GL_UNUSED,
 
 		for (size_t i = 0; i < *out_n_dicts; i++) {
 			entry = aspell_dict_info_enumeration_next (dels);
-			/* FIXME: should this be entry->code or entry->name ? */
-			out_list[i] = g_strdup (entry->code);
+			out_list[i] = g_strdup (entry->name);
 		}
 
 		delete_aspell_dict_info_enumeration (dels);
