@@ -1,5 +1,6 @@
 /* enchant
  * Copyright (C) 2003 Dom Lachowicz
+ * Copyright (C) 2017-2024 Reuben Thomas
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -11,13 +12,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along along with this program; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
- * In addition, as a special exception, Dom Lachowicz
- * gives permission to link the code of this program with
+ * In addition, as a special exception, the copyright holders
+ * give permission to link the code of this program with
  * non-LGPL Spelling Provider libraries (eg: a MSFT Office
  * spell checker backend) and distribute linked combinations including
  * the two.  You must obey the GNU Lesser General Public License in all
@@ -51,30 +51,63 @@ typedef struct str_enchant_provider EnchantProvider;
  */
 char *enchant_get_user_language(void);
 
+/**
+ * enchant_get_user_config_dir
+ *
+ * Returns a string giving the location of the user's Enchant configuration
+ * directory, or NULL on error, or if none exists. Defaults to the value of
+ * the environment variable ENCHANT_CONFIG_DIR; if that is not set, then
+ * glib's g_get_user_config_dir() is called to get the user's configuration
+ * directory, and the sub-directory "enchant" is appended.
+ *
+ * The returned string must be g_free'd.
+ */
 char *enchant_get_user_config_dir (void);
+
+/**
+ * enchant_get_user_dict_dir
+ *
+ * Returns the user dictionary directory for the given provider, or NULL on
+ * error, or if none exists.
+ *
+ * The return value must be g_free'd.
+ */
+char *enchant_get_user_dict_dir (EnchantProvider * provider);
+
+/**
+ * enchant_get_conf_dirs
+ *
+ * Returns a list (GSList *) of configuration directories, in the order in
+ * which they are used, or NULL on error.
+ *
+ * The following directories are in the list:
+ *
+ *  + Enchant's internal configuration directory (pkgdatadir)
+ *  + The system configuration directory (sysconfdir/enchant)
+ *  + The user configuration directory, as returned by
+ *     enchant_get_user_config_dir(), if it exists.
+ */
 GSList *enchant_get_conf_dirs (void);
 
 /**
  * enchant_get_prefix_dir
  *
- * Returns a string giving the location of the base directory
- * of the enchant installation.  This corresponds roughly to
- * the --prefix option given to ./configure when enchant is
- * compiled, except it is determined at runtime based on the location
- * of the enchant library.
- *
- * Returns: the prefix dir. Must be free'd.
+ * Returns a string giving the location of the base directory of the enchant
+ * installation. This corresponds roughly to the --prefix option given to
+ * ./configure when enchant is compiled, except it is determined at runtime
+ * based on the location of the enchant library.
  *
+ * The return value must be free'd.
  */
 char *enchant_get_prefix_dir(void);
 
 /**
  * enchant_relocate
  *
- * Returns a string giving the relocated path according to the location of the
- * base directory of the enchant installation.
+ * Returns a string giving the relocated path according to the location of
+ * the base directory of the enchant installation.
  *
- * Returns: the relocated path. Must be free'd.
+ * The return value must be free'd.
  */
 char *enchant_relocate (const char *path);
 
@@ -93,8 +126,8 @@ void enchant_dict_set_error (EnchantDict * dict, const char * const err);
  * @provider: A non-null provider
  * @err: A non-null error message
  *
- * Sets the current runtime error to @err. This API is private to
- * the providers.
+ * Sets the current runtime error to @err. This API is private to the
+ * providers.
  */
 void enchant_provider_set_error (EnchantProvider * provider, const char * const err);
 
@@ -105,23 +138,16 @@ struct str_enchant_dict
 
 	int (*check) (struct str_enchant_dict * me, const char *const word,
 			  size_t len);
-	
+
 	/* returns utf8*/
 	char **(*suggest) (struct str_enchant_dict * me,
 			   const char *const word, size_t len,
 			   size_t * out_n_suggs);
-	
-	void (*add_to_personal) (struct str_enchant_dict * me,
-				 const char *const word, size_t len);
-	
+
 	void (*add_to_session) (struct str_enchant_dict * me,
 				const char *const word, size_t len);
-	
-	void (*store_replacement) (struct str_enchant_dict * me,
-				   const char *const mis, size_t mis_len,
-				   const char *const cor, size_t cor_len);
-	
-	void (*add_to_exclude) (struct str_enchant_dict * me,
+
+	void (*remove_from_session) (struct str_enchant_dict * me,
 				const char *const word, size_t len);
 
 	const char * (*get_extra_word_characters) (struct str_enchant_dict * me);
@@ -129,21 +155,21 @@ struct str_enchant_dict
 	int (*is_word_character) (struct str_enchant_dict * me,
 				  uint32_t uc_in, size_t n);
 };
-	
+
 struct str_enchant_provider
 {
 	void *user_data;
 	void *enchant_private_data;
 	EnchantBroker * owner;
-	
+
 	void (*dispose) (struct str_enchant_provider * me);
-	
+
 	EnchantDict *(*request_dict) (struct str_enchant_provider * me,
 				      const char *const tag);
-	
+
 	void (*dispose_dict) (struct str_enchant_provider * me,
 				  EnchantDict * dict);
-	
+
 	int (*dictionary_exists) (struct str_enchant_provider * me,
 				  const char *const tag);
 
@@ -160,4 +186,4 @@ struct str_enchant_provider
 }
 #endif
 
-#endif /* ENCHANT_H */
+#endif /* ENCHANT_PROVIDER_H */
