@@ -119,6 +119,15 @@ enchant_get_user_config_dir (void)
 	return g_build_filename (g_get_user_config_dir (), "enchant", NULL);
 }
 
+_GL_ATTRIBUTE_MALLOC char *
+enchant_get_user_dict_dir (EnchantProvider *provider)
+{
+	char *config_dir = enchant_get_user_config_dir ();
+	gchar *dir = g_build_filename (config_dir, provider->identify(provider), NULL);
+	g_free (config_dir);
+	return dir;
+}
+
 GSList *
 enchant_get_conf_dirs (void)
 {
@@ -128,13 +137,13 @@ enchant_get_conf_dirs (void)
 	char *pkgconfdir = NULL;
 	char *user_config_dir = NULL;
 
-	if ((pkgdatadir = enchant_relocate (PKGDATADIR)) == NULL)
+	if ((pkgdatadir = enchant_relocate (PKGDATADIR "-" ENCHANT_MAJOR_VERSION)) == NULL)
 		goto error_exit;
 	conf_dirs = g_slist_append (conf_dirs, pkgdatadir);
 
 	if ((sysconfdir = enchant_relocate (SYSCONFDIR)) == NULL)
 		goto error_exit;
-	if ((pkgconfdir = g_build_filename (sysconfdir, "enchant", NULL)) == NULL)
+	if ((pkgconfdir = g_build_filename (sysconfdir, "enchant-" ENCHANT_MAJOR_VERSION, NULL)) == NULL)
 		goto error_exit;
 	conf_dirs = g_slist_append (conf_dirs, pkgconfdir);
 	free (sysconfdir);
@@ -150,7 +159,7 @@ enchant_get_conf_dirs (void)
 	free (pkgdatadir);
 	free (sysconfdir);
 	g_free (pkgconfdir);
-	free (user_config_dir);
+	g_free (user_config_dir);
 	return NULL;
 }
 
@@ -773,9 +782,14 @@ enchant_load_providers (EnchantBroker * broker)
 static void
 enchant_load_ordering_from_file (EnchantBroker * broker, const char * file)
 {
-	GIOChannel * ch = g_io_channel_new_file (file, "r", NULL);
-	if (!ch)
+	GError *err = NULL;
+	GIOChannel * ch = g_io_channel_new_file (file, "r", &err);
+	g_assert ((ch == NULL && err != NULL) || (ch != NULL && err == NULL));
+	if (err != NULL) {
+		g_debug ("could not open ordering file %s: %s", file, err->message);
+		g_error_free (err);
 		return;
+	}
 
 	g_debug("reading ordering file %s", file);
 	gchar *line;
@@ -1053,7 +1067,9 @@ enchant_broker_list_dicts (EnchantBroker * broker, EnchantDictDescribeFn fn, voi
 	GHashTable *tag_map = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
 	enchant_broker_clear_error (broker);
-	g_debug("enchant_broker_list_dicts");
+	g_debug("listing dictionaries");
+	if (broker->provider_list == NULL)
+		g_debug("no providers found!");
 
 	for (GSList *list = broker->provider_list; list != NULL; list = g_slist_next (list))
 		{
